@@ -5,6 +5,7 @@ This is the test case for the savefile.
 
 import unittest
 
+from pcapfile import savefile
 from pcapfile import linklayer
 from pcapfile.protocols.linklayer import ethernet
 
@@ -17,7 +18,10 @@ class TestCase(unittest.TestCase):
     capfile = None
 
     def init_capfile(self, layers=0):
-        self.capfile = savefile.load_savefile(open('test_data/test.pcap', 'r'), 
+        """
+        Initialise capture file.
+        """
+        self.capfile = savefile.load_savefile(open('test_data/test.pcap', 'r'),
                                               layers=layers)
 
     @classmethod
@@ -36,9 +40,9 @@ class TestCase(unittest.TestCase):
 
     def test_lookup(self):
         """
-        Test the strings returned by the short lookup functions. 
+        Test the strings returned by the short lookup functions.
         """
-        self.assertEqual('LINKTYPE_ETHERNET', linklayer.lookup(1), 
+        self.assertEqual('LINKTYPE_ETHERNET', linklayer.lookup(1),
                          'invalid long name')
-        self.assertEqual('ethernet', linklayer.slookup(1), 
+        self.assertEqual('ethernet', linklayer.slookup(1),
                          'invalid short name')
